@@ -1,7 +1,8 @@
 from abc import ABC, abstractmethod
-from typing import NamedTuple, Union
+from typing import NamedTuple, TypeVar, Union
 
 from odd_models.models import DataEntityList
+from oddrn_generator import Generator
 
 from odd_collector_sdk.domain.plugin import Plugin
 
@@ -16,6 +17,23 @@ class AbstractAdapter(ABC):
         pass
 
 
+Config = TypeVar("Config", bound=Plugin)
+
+
+class BaseAdapter(AbstractAdapter, ABC):
+    def __init__(self, config: Config) -> None:
+        super().__init__()
+        self.config = config
+        self.generator = self.create_generator()
+
+    def get_data_source_oddrn(self) -> str:
+        return self.generator.get_data_source_oddrn()
+
+    @abstractmethod
+    def create_generator(self) -> Generator:
+        ...
+
+
 class AsyncAbstractAdapter(ABC):
     @abstractmethod
     async def get_data_source_oddrn(self) -> str:
